<?php
/*
Plugin Name: Usernoise
Plugin URI: mailto: hello@karevn.com
Description: Usernoise is a modal contact / feedback form with flexible interface.
Version: 0.2.2
Author: Nikolay Karev
Author URI: mailto: hello@karevn.com
*/

define('FEEDBACK', 'feedback');
define('FEEDBACK_TYPE', 'feedback_type');
define('USERNOISE', 'usernoise');
define('USERNOISE_PATH', ABSPATH . "wp-content/plugins/" . USERNOISE);

define('UN_FEEDBACK_FORM_TITLE', 'un_feedback_form_title');
define('UN_USE_FONT', 'un_use_font');
define('UN_FEEDBACK_FORM_TEXT', 'un_feedback_form_text');
define('UN_FEEDBACK_BUTTON_TEXT', 'un_feedback_button_text');
define('UN_FEEDBACK_BUTTON_COLOR', 'un_feedback_button_color');
define('UN_FEEDBACK_BUTTON_POSITION', 'un_feedback_button_position');
define('UN_FEEDBACK_BUTTON_TEXT_COLOR', 'un_feedback_button_text_color');
define('UN_SUBMIT_FEEDBACK_BUTTON_TEXT', 'un_submit_feedback_button_text');
define('UN_FEEDBACK_FORM_SHOW_SUMMARY', 'un_feedback_form_show_summary');
define('UN_FEEDBACK_FORM_SHOW_TYPE', 'un_feedback_form_show_type');
define('UN_FEEDBACK_FORM_SHOW_EMAIL', 'un_feedback_form_show_email');
define('UN_ADMIN_NOTIFY_ON_FEEDBACK', 'un_admin_notify_on_feedback');
define('UN_THANKYOU_TITLE', 'un_thankyou_title');
define('UN_THANKYOU_TEXT', 'un_thankyou_text');

define('UN_VERSION', '0.2.1');

require_once('vendor/html-helpers/html-helpers.php');
require_once('inc/l10n.php');
require_once('inc/model.php');
require_once('inc/template.php');
if (is_admin()){
	require_once('admin/editor-page.php');
	require_once('admin/menu.php');
	require_once('admin/feedback-list.php');
	require_once('admin/settings.php');
	require_once('admin/dashboard.php');
	if (defined('DOING_AJAX')){
		require_once('inc/controller.php');
	}
} else {
	require_once('admin/admin-bar.php');
	require_once('inc/integration.php');
	require_once('inc/controller.php');
}

if (file_exists(usernoise_path('/pro/pro.php'))){
	require_once(usernoise_path('/pro/pro.php'));
}

require('inc/globals.php');

if (file_exists(usernoise_path("/pro/inc/globals.php"))){
	require_once(usernoise_path("/pro/inc/globals.php"));
}

function un_get_default_options(){
	return array(
		UN_USE_FONT => '',
		UN_FEEDBACK_BUTTON_TEXT => _x('Feedback', 'button', 'usernoise'),
		UN_FEEDBACK_BUTTON_COLOR => '#404040',
		UN_FEEDBACK_BUTTON_TEXT_COLOR => '#FFFFFF',
		UN_FEEDBACK_BUTTON_POSITION => 'left',
		UN_FEEDBACK_FORM_TITLE => _x('Feedback', 'form', 'usernoise'),
		UN_FEEDBACK_FORM_TEXT => __('Please tell us what do you think, any kind of feedback is highly appreciated.', 'usernoise'),
		UN_FEEDBACK_FORM_SHOW_SUMMARY => '1',
		UN_FEEDBACK_FORM_SHOW_TYPE => '1',
		UN_FEEDBACK_FORM_SHOW_EMAIL => '1',
		UN_SUBMIT_FEEDBACK_BUTTON_TEXT => __('Submit feedback', 'usernoise'), 
		UN_THANKYOU_TITLE => __('Thank you', 'usernoise'),
		UN_THANKYOU_TEXT => __('Your feedback have been received.', 'usernoise'),
		UN_ADMIN_NOTIFY_ON_FEEDBACK => '1',
		UN_SUBMIT_FEEDBACK_BUTTON_TEXT => __('Submit feedback', 'usernoise')
	);
}

function un_activation_hook(){
	global $un_default_options;
	$un_model_class = apply_filters('un_model_class', 'UN_Model');
	$un_model = new $un_model_class;
	$un_model->action_init();
	$un_l10n_class = apply_filters('un_l10n_class', 'UN_L10n');
	$un_l10n = new $un_l10n_class;
	$un_l10n->action_init();
	foreach(array(
		'idea' => __('Idea'), 'question' => __('Question', 'usernoise'), 'problem' => __('Problem', 'usernoise'),
		'praise' => __('Praise', 'usernoise')) as $type => $value){
		if (null == get_term_by('slug', $type, 'feedback_type')){
			wp_insert_term($value, FEEDBACK_TYPE, array('slug' => $type));
		}
	}
	foreach(un_get_default_options() as $name => $value){
		if (get_option($name, null) === null){
			add_option($name, $value, false, false);
		}
	}
	if (!get_option('un_version')){
		add_option('un_version', UN_VERSION);
		global $wpdb;
		$wpdb->query("UPDATE $wpdb->postmeta 
			INNER JOIN $wpdb->posts ON $wpdb->posts.ID = $wpdb->postmeta.post_id
			SET meta_key = '_email' 
			WHERE meta_key = 'email' AND post_type = 'feedback'
			");
	}
}

function un_deactivation_hook(){
	foreach(array_keys(un_get_default_options()) as $default_option){
		delete_option($default_option);
	}
	delete_option(UN_VERSION);
}

register_deactivation_hook(__FILE__, 'un_deactivation_hook');
register_activation_hook(__FILE__, 'un_activation_hook');